@@ -17,6 +17,25 @@ from dateutil import parser
 
 from . import dx_logging as log
 
+class DXIConfigConstantsHelper(object):
+    DXIDATA = "dxi-data"
+    CONF = '/config/dxtools.conf'
+    LOG= '/logs/'
+
+    ROOT_DEFAULT = '../../'
+
+    def get_dxidata_root(self):
+        root = os.environ.get('DXI_DIR', self.ROOT_DEFAULT)
+        if not root.endswith('/'):
+            root = root + '/'
+        return root + self.DXIDATA
+
+    def get_config(self):
+        return self.get_dxidata_root() + self.CONF
+
+    def get_logdir(self):
+        return self.get_dxidata_root() + self.LOG
+
 def find_config_path(config_file_path):
     """
     Locate the config path if the default is passed.
@@ -42,14 +61,8 @@ def find_config_path(config_file_path):
                     f"Config location passed to dxi does not exist. "
                     f"Scanning default location."
                 )
-                config_file_path = str(
-                    os.path.join(
-                        os.path.dirname(__file__),
-                        "..",
-                        "..",
-                        "dxi-data/config/dxtools.conf",
-                    )
-                )
+                config_file_path = DXIConfigConstantsHelper().get_config()
+
             if not os.path.isfile(config_file_path):
                 err_msg = (
                     f"Error: Could not find dxtools.conf at the "
